Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(649)

Unified Diff: test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js

Issue 2244003003: Change which ExceptionEvents are triggered by Promises (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Fixed typos Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js
diff --git a/test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js b/test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js
index b7c5861c1f0a5672a396cc37ee55516e5e306a8f..cd13dbf9d2c5a720a3edc5219d5afa83209890ab 100644
--- a/test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js
+++ b/test/mjsunit/es6/debug-promises/reject-caught-by-default-reject-handler.js
@@ -44,8 +44,8 @@ function listener(event, exec_state, event_data, data) {
assertTrue(event_data.uncaught());
assertTrue(event_data.promise() instanceof Promise);
if (expected_events == 1) {
- // p1 is rejected, uncaught except for its default reject handler.
- assertEquals(0, exec_state.frameCount());
+ // p1 is rejected, uncaught, with the error from the Promise.reject line
+ assertNotNull(event_data.sourceLineText().match("Promise.reject"));
assertSame(p1, event_data.promise());
} else {
// p2 is rejected by p1's default reject handler.
« no previous file with comments | « test/mjsunit/es6/debug-promises/promise-race-uncaught.js ('k') | test/mjsunit/es6/debug-promises/reject-uncaught-all.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698